@@ -87,6 +87,8 @@ static char *ignored_words[] = {
 	"Inc.",
 	"Inc",
 	"Ltd.",
+	"Limited.",
+	"Intel?",
 	"chipset",
 	"adapter",
 	"[hex]",
@@ -109,6 +111,10 @@ static char *ignored_phrases[] = {
 	"Wireless cardbus",
 	"Wireless LAN PC Card",
 	"Technology Group Ltd.",
+	"Communication S.p.A.",
+	"Business Mobile Networks BV",
+	"Mobile Broadband Minicard Composite Device",
+	"Mobile AB",
 	NULL
 };
 
